README sections
# 01 Title
# mysklearn
# 02 Description and Features
# mysklearn is a package for complete **linear regression** in Python.
# 03 Installation
## Installation You can install this package using
``` pip install mysklearn ```
# Usage examples
# Contributing
# License